==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/space/messages/an/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Iste espacio encara ye vuido!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Iste espacio encara ye vuido!</b><br>Empecipia publicando bella cosa aquí...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>No yes miembro d\'iste espacio y no i hai conteniu encara!</b>',
    '<strong>Space</strong> members' => '<strong>Miembros</strong> de l\'espacio',
    '<strong>Space</strong> menu' => '<strong>Menu</strong> d\'o espacio',
    'About' => 'Quanto a',
    'Accept' => 'Akzeptieren',
    'Archived' => 'Archivau',
    'Cancel' => 'Cancelar',
    'Close' => 'Zavřít',
    'Created At' => 'Creyau o',
    'Created By' => 'Creyau per',
    'Default' => 'Defecto',
    'Delete' => 'Eliminar',
    'Description' => 'Descripción',
    'Follow' => 'Seguir',
    'Followers' => 'Seguidors',
    'Following' => 'Seguindo',
    'Guests' => ' ',
    'Last Visit' => 'Zaguera visita',
    'Login' => 'Iniciar sesión',
    'Members' => 'Miembros',
    'My Space List' => 'A mía lista d\'espacios',
    'My space summary' => 'O mío resumen d\'os espacios',
    'Public' => 'Publico',
    'Send' => 'Ninviar',
    'Settings' => 'Achustes',
    'Sorting' => 'Ordenación',
    'Space' => 'Espacio',
    'Space directory' => 'Directorio d\'espacios',
    'Space is invisible!' => 'L\'espacio ye invisible!',
    'Spaces' => 'Espacios',
    'Stream' => 'Actividatz',
    'Tags' => 'Etiquetas',
    'Updated At' => 'Actualizau o',
    'Updated By' => 'Actualizau per',
    'User not found!' => ' Gebruikers niet gevonden!',
    'Users' => 'Usuarios',
    'Visibility' => 'Visibilidat',
    'You need to login to view contents of this space!' => 'Cal connectar-se pa veyer os contenius d\'iste espacio!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Invite</strong> members' => '',
    '<strong>New</strong> member request' => '',
    '<strong>New</strong> spaces' => '',
    '<strong>Request</strong> Membership' => '',
    '<strong>Space</strong> followers' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Accept Invite' => '',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '',
    'Add users without invitation' => '',
    'Admin' => '',
    'Administrator:' => '',
    'Administrators' => '',
    'Any' => '',
    'As owner you cannot revoke your membership!' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Color' => '',
    'Could not request membership!' => '',
    'Decline' => '',
    'Decline Invite' => '',
    'Default content visibility' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Done' => '',
    'Email addresses' => '',
    'Everyone can enter' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage' => '',
    'Homepage (Guests)' => '',
    'I want to become a member because...' => '',
    'Invite' => '',
    'Invite and request' => '',
    'Invite by email' => '',
    'Invites' => '',
    'Join' => '',
    'Join Policy' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Moderators' => '',
    'Name' => '',
    'Neither..nor' => '',
    'New user by e-mail (comma separated)' => '',
    'New user?' => '',
    'Newest first' => '',
    'No results found!' => '',
    'No spaces found.' => '',
    'Oldest first' => '',
    'Only by invite' => '',
    'Originator User ID' => '',
    'Owner' => '',
    'Owner:' => '',
    'Pending' => '',
    'Pick users' => '',
    'Posts' => '',
    'Private' => '',
    'Private (Invisible)' => '',
    'Public (Members & Guests)' => '',
    'Public (Members only)' => '',
    'Public (Registered users only)' => '',
    'Request Message' => '',
    'Role' => '',
    'Search...' => '',
    'See all' => '',
    'Select all registered users' => '',
    'Settings could not be saved!' => '',
    'Show all' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'Space Visibility' => '',
    'Status' => '',
    'There is no pending invite!' => '',
    'This action is only available for workspace members!' => '',
    'This user is already a member of this space.' => '',
    'This user is not a member of this space.' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Updated by' => '',
    'User \'{username}\' is already a member of this space!' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'Users has been invited.' => '',
    'Visible for all (members and guests)' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You are not allowed to join this space!' => '',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You cannot create private visible spaces!' => '',
    'You cannot create public visible spaces!' => '',
    'Your Message' => '',
    'Your request was successfully submitted to the space administrators.' => '',
    '{count} members' => '',
    '{email} is not valid!' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/space/messages/an/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Iste espacio encara ye vuido!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Iste espacio encara ye vuido!</b><br>Empecipia publicando bella cosa aquí...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>No yes miembro d\'iste espacio y no i hai conteniu encara!</b>',
    '<strong>Space</strong> members' => '<strong>Miembros</strong> de l\'espacio',
    '<strong>Space</strong> menu' => '<strong>Menu</strong> d\'o espacio',
    'About' => 'Quanto a',
    'Accept' => 'Akzeptieren',
    'Archived' => 'Archivau',
    'Cancel' => 'Cancelar',
    'Close' => 'Zavřít',
    'Created At' => 'Creyau o',
    'Created By' => 'Creyau per',
    'Default' => 'Defecto',
    'Delete' => 'Eliminar',
    'Description' => 'Descripción',
    'Follow' => 'Seguir',
    'Followers' => 'Seguidors',
    'Following' => 'Seguindo',
    'Guests' => ' ',
    'Last Visit' => 'Zaguera visita',
    'Login' => 'Iniciar sesión',
    'Members' => 'Miembros',
    'My Space List' => 'A mía lista d\'espacios',
    'My space summary' => 'O mío resumen d\'os espacios',
    'Public' => 'Publico',
    'Send' => 'Ninviar',
    'Settings' => 'Achustes',
    'Sorting' => 'Ordenación',
    'Space' => 'Espacio',
    'Space directory' => 'Directorio d\'espacios',
    'Space is invisible!' => 'L\'espacio ye invisible!',
    'Spaces' => 'Espacios',
    'Stream' => 'Actividatz',
    'Tags' => 'Etiquetas',
    'Updated At' => 'Actualizau o',
    'Updated By' => 'Actualizau per',
    'User not found!' => ' Gebruikers niet gevonden!',
    'Users' => 'Usuarios',
    'Visibility' => 'Visibilidat',
    'You need to login to view contents of this space!' => 'Cal connectar-se pa veyer os contenius d\'iste espacio!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Invite</strong> members' => '',
    '<strong>New</strong> member request' => '',
    '<strong>New</strong> spaces' => '',
    '<strong>Request</strong> Membership' => '',
    '<strong>Space</strong> followers' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Accept Invite' => '',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '',
    'Add users without invitation' => '',
    'Admin' => '',
    'Administrator:' => '',
    'Administrators' => '',
    'Any' => '',
    'As owner you cannot revoke your membership!' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Color' => '',
    'Could not request membership!' => '',
    'Create new link' => '',
    'Decline' => '',
    'Decline Invite' => '',
    'Default content visibility' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Done' => '',
    'Email addresses' => '',
    'Everyone can enter' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage' => '',
    'Homepage (Non-members)' => '',
    'I want to become a member because...' => '',
    'Invite' => '',
    'Invite and request' => '',
    'Invite by email' => '',
    'Invite by link' => '',
    'Invite link' => '',
    'Invites' => '',
    'Join' => '',
    'Join Policy' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Moderators' => '',
    'Name' => '',
    'Neither..nor' => '',
    'New user by e-mail (comma separated)' => '',
    'New user?' => '',
    'Newest first' => '',
    'No results found!' => '',
    'No spaces found.' => '',
    'Oldest first' => '',
    'Only by invite' => '',
    'Originator User ID' => '',
    'Owner' => '',
    'Owner:' => '',
    'Pending' => '',
    'Pick users' => '',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => '',
    'Posts' => '',
    'Private' => '',
    'Private (Invisible)' => '',
    'Public (Members & Guests)' => '',
    'Public (Members only)' => '',
    'Public (Registered users only)' => '',
    'Request Message' => '',
    'Role' => '',
    'Search...' => '',
    'See all' => '',
    'Select all registered users' => '',
    'Send the link via email' => '',
    'Settings could not be saved!' => '',
    'Show all' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'Space Visibility' => '',
    'Status' => '',
    'The default homepage for members of this Space' => '',
    'The default homepage for non-members and guests visiting this Space' => '',
    'The secure link has been copied in your clipboard!' => '',
    'There is no pending invite!' => '',
    'This action is only available for workspace members!' => '',
    'This user is already a member of this space.' => '',
    'This user is not a member of this space.' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Updated by' => '',
    'User \'{username}\' is already a member of this space!' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'Users has been invited.' => '',
    'Visible for all (members and guests)' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You are not allowed to join this space!' => '',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => '',
    'You cannot create private visible spaces!' => '',
    'You cannot create public visible spaces!' => '',
    'Your Message' => '',
    'Your request was successfully submitted to the space administrators.' => '',
    '{count} members' => '',
    '{email} is not valid!' => '',
];
